# Specification File to generate scc-rpm.
# Copyright (C) 2001-2004 Open Challenge B.V.
# Copyright (C) 2004-2005 OpenEyeT Professional Services.
# Copyright (C) 2005-2009 QNH.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; see the file COPYING.
# If not, write to the Free Software Foundation,
# 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
#
# Contact information: http://scc.qnh-infrastructure.nl/index.html 

# SCC-release:	1.9.28
# file-version:	$Revision: 1.51 $

# To build the rpm, use the commands:
#
#	cd software
#	mkdir -p /tmp/RPMS/noarch
#	rpmbuild	--define='_rpmdir /tmp/RPMS'	\
#			-bb				\
#			../rpm-scc.spec

Summary: System Configuration Collector
# The Summary: line should be expanded to about here -----^
Name: scc
Version: TO_BE_CHANGED
Release: TO_BE_CHANGED
Group: Utilities/System
License: GPL
BuildRoot: /tmp/ScC_BuIlD/software
URL: http://scc.qnh-infrastructure.nl/index.html
BuildArchitectures: noarch
Vendor: QNH

%description
System Configuration Collector.

%pre
# file-version:	$Revision: 1.5 $

# Do not use POSIX features in this script as it can be sourced by a non-POSIX system shell!

SCC_BIN=/opt/scc/bin
SCC_TOP=/var/opt/scc
export SCC_BIN SCC_TOP

SCC_DATA=${SCC_TOP}/data
SCC_TMP=${SCC_TOP}/tmp
SCC_CONF=/etc/opt/scc/conf
export SCC_DATA SCC_TMP SCC_CONF

# Avoid too strict permissions for newly created /var/opt directory.
# Otherwise scc-srv will not work correctly.
umask 022
mkdir -p ${SCC_TOP} 2>/dev/null

umask 077
mkdir -p ${SCC_DATA} ${SCC_TMP} 2>/dev/null

name=`uname -n | sed -e 's/\..*//'`

# Just before the install we run the current version to detect any changes
# in the configuration of the system. After the install we remove the current
# snapshot to avoid comparison of the snapshots. This enables us to change
# the format of the snapshots without flooding the log files with differences.
if [ -x ${SCC_BIN}/scc-log ]
then
	echo "NOTE:    Running scc to create a snapshot with the current"
	echo "NOTE:    version of the software. This may take some minutes."

	if [ -f ${SCC_DATA}/scc.${name}.lock ]
	then
		echo "ERROR:   install aborted, another instance of scc"
		echo "ERROR:   is active."
		exit 2
	else
		# During installs on HP-UX stm often hangs; do not run it.
		SCC_IGNORE_STM="yes";			export SCC_IGNORE_STM

		# During installs, rpm is locked; indicate the installation phase:
		SCC_INSTALL_PHASE="preinstall";		export SCC_INSTALL_PHASE

		${SCC_BIN}/scc-log
	fi
fi

# Avoid that scc is started between the pre- and the post-install.
# We create the lock-file for scc-log together with a file indicating to 
# the postinstall that the install is running.
touch ${SCC_DATA}/scc.${name}.lock ${SCC_DATA}/scc.${name}.install

exit 0

%post
# file-version: $Revision: 1.5 $

# Do not use POSIX features in this script as it can be sourced by a non-POSIX system shell!

SCC_BIN=/opt/scc/bin
SCC_TOP=/var/opt/scc
export SCC_BIN SCC_TOP

SCC_DATA=${SCC_TOP}/data
SCC_TMP=${SCC_TOP}/tmp
SCC_CONF=/etc/opt/scc/conf
SCC_NEWCONF=/etc/opt/scc/newconfig
export SCC_DATA SCC_TMP SCC_CONF

umask 077

# Just before the install we run the current version to detect any changes
# in the configuration of the system. After the install we remove the current
# snapshot to avoid comparison of the snapshots. This enables us to change
# the format of the snapshots without flooding the log files with differences.

name=`uname -n | sed -e 's/\..*//'`

if [ ! -f ${SCC_DATA}/scc.${name}.lock -a ! -f ${SCC_DATA}/scc.${name}.install ]
then
	echo "WARNING: Lock- and or install-file do not exist during install."
	exit 2
fi

# Remove current snapshot and create new snapshot.
echo "NOTE:    Running scc to create a snapshot with the new version"
echo "NOTE:    of the software. This may take some minutes."

# During installs on HP-UX, stm often hangs; do not run it.
SCC_IGNORE_STM="yes";			export SCC_IGNORE_STM

# During installs, rpm is locked; indicate the installation phase:
SCC_INSTALL_PHASE="postinstall";	export SCC_INSTALL_PHASE

rm -f ${SCC_DATA}/scc.${name}.lock ${SCC_DATA}/scc.${name}.install
${SCC_BIN}/scc-log -c "install of SCC release 1.9.28" -r

# Do not overwrite an existing stylesheet.
if [ ! -f ${SCC_DATA}/style.css ]
then
	cp ${SCC_NEWCONF}/style.css ${SCC_DATA}
	chmod 400 ${SCC_DATA}/style.css
fi

echo "NOTE:    The snapshot and logbook can be found in ${SCC_DATA}"

exit 0

%postun
# file-version:	$Revision: 1.5 $

# Do not use POSIX features in this script as it can be sourced by a non-POSIX system shell!

SCC_BIN=/opt/scc/bin
SCC_TOP=/var/opt/scc
export SCC_BIN SCC_TOP

scripts_present=`ls ${SCC_BIN} 2>/dev/null`
if [ -n "${scripts_present}" ]
then
	# Upon upgrading by means of rpm -U scc-X.rpm,
	# the postremove is called after installing the new version.
	# In that case we should not remove anything.
	:
else
	# This is the "real" remove. Remove additional directories and files.
	rm -rf ${SCC_TOP} /opt/scc /etc/opt/scc
fi

exit 0

%files
%defattr(755,root,root)
%dir /./etc/
%dir /./etc/opt/
%defattr(700,root,root)
%dir /./etc/opt/scc/
%dir /./etc/opt/scc/conf
%dir /./etc/opt/scc/newconfig
/./etc/opt/scc/newconfig/*
%defattr(755,root,root)
%dir /./opt/
%defattr(711,root,root)
%dir /./opt/scc/
%dir /./opt/scc/bin/
%defattr(500,root,root)
/./opt/scc/bin/*
%defattr(700,root,root)
%dir /./opt/scc/doc/
%defattr(400,root,root)
%doc /./opt/scc/doc/*
%defattr(755,root,root)
%dir /./opt/scc/man/
%dir /./opt/scc/man/man1/
%defattr(444,root,root)
%doc /./opt/scc/man/man1/*
%defattr(755,root,root)
%dir /./opt/scc/man/man4/
%dir /./opt/scc/man/man5/
%defattr(444,root,root)
%doc /./opt/scc/man/man4/scc.4
%doc /./opt/scc/man/man5/scc.5
